# Contributing Guide

## Issue Tracker

We use an [issue tracker](https://github.com/sony/model_optimization/issues) hosted in the [MCT GitHub repository](https://github.com/sony/model_optimization).
If you encounter any bugs, or come up with any feature requests, please first search if there is an already existing issue. If you can not find any, please feel free to post a new issue.


## Contributing by Pull Request


We appreciate contributors in the community, that are willing to improve MCT.
We basically follow the development style used in many GitHub repositories.

1. Search existing issues and/or pull request in
   [the GitHub repository](https://github.com/sony/model_optimization).

2. If it doesn't exist, post an issue for the feature proposal.

3. Fork the repository, and develop your feature in the forked repo.

4. Create a pull request of your development branch to MCT's `main` branch.
   Our maintainers will then review your changes.

5. Once your change is finalized, the maintainer will merge your change.
